# Generated by Django 3.2.13 on 2022-07-25 08:37

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='TopicCallback',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('topic', models.CharField(help_text='Topic you are subscribing to.', max_length=128)),
                ('protocol', models.CharField(choices=[('https', 'HTTPS'), ('http', 'HTTP'), ('email', 'Email'), ('lambda', 'AWS Lambda'), ('sqs', 'Amazon SQS')], max_length=32)),
                ('callback', models.URLField(help_text='Fully qualified callback URI that messages for the topic will     be pushed to', max_length=255)),
                ('enabled', models.BooleanField(default=True)),
                ('arn', models.CharField(blank=True, max_length=255, null=True)),
                ('created', models.DateTimeField(auto_now_add=True, db_index=True)),
                ('modified', models.DateTimeField(auto_now=True, db_index=True)),
            ],
            options={
                'verbose_name': 'Topic Callback',
                'verbose_name_plural': 'Topic Callbacks',
            },
        ),
    ]
