import setuptools

setuptools.setup(
    # name='4sure_message_wrapper',
    # version='0.0.1',
    # author='Andrew Simpson',
    # author_email='andrew.simpson@4-sure.net',
    # description='Message wrapper to add messaging functionality to our microservices',
    # long_description=long_description,
    # long_description_content_type="text/markdown",
    # url='https://bitbucket.org/101collective/4sure_message_wrapper',
    # project_urls = {
    #     "Bug Tracker": "https://bitbucket.org/101collective/4sure_message_wrapper/issues"
    # },
    # license='MIT',
    # packages=['messages'],
    # install_requires=['requests', 'boto3'],
)
